@@ -20,9 +20,9 @@ module Redland
 
     # You shouldn't use this. Used internally for cleanup.
     def Stream.create_finalizer(stream)
-      proc {|id| "Finalizer on #{id}"
-        #      puts "closing model"
-        Redland::librdf_free_model(stream)
+      proc {|id| # "Finalizer on #{id}"
+        #puts "closing stream"
+        Redland::librdf_free_stream(stream)
       }
     end
 
@@ -107,6 +107,16 @@ module Redland
         my_node=Redland.librdf_iterator_next(@iterator)
       end
 
+      ObjectSpace.define_finalizer(self,NodeIterator.create_finalizer(@iterator))
     end
+
+    # You shouldn't use this. Used internally for cleanup.
+    def NodeIterator.create_finalizer(iterator)
+      proc {|id| # "Finalizer on #{id}"
+        #puts "closing iterator"
+        Redland::librdf_free_iterator(iterator)
+      }
+    end
+
   end
 end
